diff mbox series

media: i2c: rdacm20: Fix format definition

Message ID 20220316210916.606929-1-jacopo+renesas@jmondi.org (mailing list archive)
State New, archived
Headers show
Series media: i2c: rdacm20: Fix format definition | expand

Commit Message

Jacopo Mondi March 16, 2022, 9:09 p.m. UTC
The RDACM20 camera supports a single image format which is currently
listed as MEDIA_BUS_FMT_UYVY8_2X8. As the video stream is transmitted on
the GMSL serial bus, the 2X8 variant does not apply.

Fix the format byusing MEDIA_BUS_FMT_UYVY8_1X16.

This fixes a runtime error which is now triggered as the MAX9286
deserializer implements .link_validate().

Signed-off-by: Jacopo Mondi <jacopo+renesas@jmondi.org>
---
 drivers/media/i2c/rdacm20.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

--
2.35.1

Comments

Laurent Pinchart March 17, 2022, 6:39 a.m. UTC | #1
Hi Jacopo,

Thank you for the patch.

On Wed, Mar 16, 2022 at 10:09:16PM +0100, Jacopo Mondi wrote:
> The RDACM20 camera supports a single image format which is currently
> listed as MEDIA_BUS_FMT_UYVY8_2X8. As the video stream is transmitted on
> the GMSL serial bus, the 2X8 variant does not apply.
> 
> Fix the format byusing MEDIA_BUS_FMT_UYVY8_1X16.

s/by/by /

> This fixes a runtime error which is now triggered as the MAX9286
> deserializer implements .link_validate().
> 
> Signed-off-by: Jacopo Mondi <jacopo+renesas@jmondi.org>

Reviewed-by: Laurent Pinchart <laurent.pinchart@ideasonboard.com>

> ---
>  drivers/media/i2c/rdacm20.c | 8 ++++----
>  1 file changed, 4 insertions(+), 4 deletions(-)
> 
> diff --git a/drivers/media/i2c/rdacm20.c b/drivers/media/i2c/rdacm20.c
> index ba956733aa89..6f23776ad214 100644
> --- a/drivers/media/i2c/rdacm20.c
> +++ b/drivers/media/i2c/rdacm20.c
> @@ -47,11 +47,11 @@
>  #define OV10635_VTS			933
> 
>  /*
> - * As the drivers supports a single MEDIA_BUS_FMT_UYVY8_2X8 format we
> + * As the drivers supports a single MEDIA_BUS_FMT_UYVY8_1X16 format we
>   * can harcode the pixel rate.
>   *
>   * PCLK is fed through the system clock, programmed @88MHz.
> - * MEDIA_BUS_FMT_UYVY8_2X8 format = 2 samples per pixel.
> + * MEDIA_BUS_FMT_UYVY8_1X16 format = 2 samples per pixel.
>   *
>   * Pixelrate = PCLK / 2
>   * FPS = (OV10635_VTS * OV10635_HTS) / PixelRate
> @@ -409,7 +409,7 @@ static int rdacm20_enum_mbus_code(struct v4l2_subdev *sd,
>  	if (code->pad || code->index > 0)
>  		return -EINVAL;
> 
> -	code->code = MEDIA_BUS_FMT_UYVY8_2X8;
> +	code->code = MEDIA_BUS_FMT_UYVY8_1X16;
> 
>  	return 0;
>  }
> @@ -425,7 +425,7 @@ static int rdacm20_get_fmt(struct v4l2_subdev *sd,
> 
>  	mf->width		= OV10635_WIDTH;
>  	mf->height		= OV10635_HEIGHT;
> -	mf->code		= MEDIA_BUS_FMT_UYVY8_2X8;
> +	mf->code		= MEDIA_BUS_FMT_UYVY8_1X16;
>  	mf->colorspace		= V4L2_COLORSPACE_RAW;
>  	mf->field		= V4L2_FIELD_NONE;
>  	mf->ycbcr_enc		= V4L2_YCBCR_ENC_601;
Kieran Bingham March 17, 2022, 9:40 a.m. UTC | #2
Hi Jacopo,

Quoting Jacopo Mondi (2022-03-16 21:09:16)
> The RDACM20 camera supports a single image format which is currently
> listed as MEDIA_BUS_FMT_UYVY8_2X8. As the video stream is transmitted on
> the GMSL serial bus, the 2X8 variant does not apply.
> 
> Fix the format byusing MEDIA_BUS_FMT_UYVY8_1X16.
> 
> This fixes a runtime error which is now triggered as the MAX9286
> deserializer implements .link_validate().

Reviewed-by: Kieran Bingham <kieran.bingham+renesas@ideasonboard.com>

> Signed-off-by: Jacopo Mondi <jacopo+renesas@jmondi.org>
> ---
>  drivers/media/i2c/rdacm20.c | 8 ++++----
>  1 file changed, 4 insertions(+), 4 deletions(-)
> 
> diff --git a/drivers/media/i2c/rdacm20.c b/drivers/media/i2c/rdacm20.c
> index ba956733aa89..6f23776ad214 100644
> --- a/drivers/media/i2c/rdacm20.c
> +++ b/drivers/media/i2c/rdacm20.c
> @@ -47,11 +47,11 @@
>  #define OV10635_VTS                    933
> 
>  /*
> - * As the drivers supports a single MEDIA_BUS_FMT_UYVY8_2X8 format we
> + * As the drivers supports a single MEDIA_BUS_FMT_UYVY8_1X16 format we
>   * can harcode the pixel rate.
>   *
>   * PCLK is fed through the system clock, programmed @88MHz.
> - * MEDIA_BUS_FMT_UYVY8_2X8 format = 2 samples per pixel.
> + * MEDIA_BUS_FMT_UYVY8_1X16 format = 2 samples per pixel.
>   *
>   * Pixelrate = PCLK / 2
>   * FPS = (OV10635_VTS * OV10635_HTS) / PixelRate
> @@ -409,7 +409,7 @@ static int rdacm20_enum_mbus_code(struct v4l2_subdev *sd,
>         if (code->pad || code->index > 0)
>                 return -EINVAL;
> 
> -       code->code = MEDIA_BUS_FMT_UYVY8_2X8;
> +       code->code = MEDIA_BUS_FMT_UYVY8_1X16;
> 
>         return 0;
>  }
> @@ -425,7 +425,7 @@ static int rdacm20_get_fmt(struct v4l2_subdev *sd,
> 
>         mf->width               = OV10635_WIDTH;
>         mf->height              = OV10635_HEIGHT;
> -       mf->code                = MEDIA_BUS_FMT_UYVY8_2X8;
> +       mf->code                = MEDIA_BUS_FMT_UYVY8_1X16;
>         mf->colorspace          = V4L2_COLORSPACE_RAW;
>         mf->field               = V4L2_FIELD_NONE;
>         mf->ycbcr_enc           = V4L2_YCBCR_ENC_601;
> --
> 2.35.1
>
diff mbox series

Patch

diff --git a/drivers/media/i2c/rdacm20.c b/drivers/media/i2c/rdacm20.c
index ba956733aa89..6f23776ad214 100644
--- a/drivers/media/i2c/rdacm20.c
+++ b/drivers/media/i2c/rdacm20.c
@@ -47,11 +47,11 @@ 
 #define OV10635_VTS			933

 /*
  * As the drivers supports a single MEDIA_BUS_FMT_UYVY8_2X8 format we
  * can harcode the pixel rate.
  *
  * PCLK is fed through the system clock, programmed @88MHz.
  * MEDIA_BUS_FMT_UYVY8_2X8 format = 2 samples per pixel.
  *
  * Pixelrate = PCLK / 2
  * FPS = (OV10635_VTS * OV10635_HTS) / PixelRate
@@ -409,7 +409,7 @@  static int rdacm20_enum_mbus_code(struct v4l2_subdev *sd,
 	if (code->pad || code->index > 0)
 		return -EINVAL;

-	code->code = MEDIA_BUS_FMT_UYVY8_2X8;
+	code->code = MEDIA_BUS_FMT_UYVY8_1X16;

 	return 0;
 }
@@ -425,7 +425,7 @@  static int rdacm20_get_fmt(struct v4l2_subdev *sd,

 	mf->width		= OV10635_WIDTH;
 	mf->height		= OV10635_HEIGHT;
-	mf->code		= MEDIA_BUS_FMT_UYVY8_2X8;
+	mf->code		= MEDIA_BUS_FMT_UYVY8_1X16;
 	mf->colorspace		= V4L2_COLORSPACE_RAW;
 	mf->field		= V4L2_FIELD_NONE;
 	mf->ycbcr_enc		= V4L2_YCBCR_ENC_601;
@@ -47,11 +47,11 @@ 

 /*
- * As the drivers supports a single MEDIA_BUS_FMT_UYVY8_2X8 format we
+ * As the drivers supports a single MEDIA_BUS_FMT_UYVY8_1X16 format we
  * can harcode the pixel rate.
  *
@@ -47,11 +47,11 @@ 
  *
  * PCLK is fed through the system clock, programmed @88MHz.
- * MEDIA_BUS_FMT_UYVY8_2X8 format = 2 samples per pixel.
+ * MEDIA_BUS_FMT_UYVY8_1X16 format = 2 samples per pixel.
  *
  * Pixelrate = PCLK / 2